;+
;

function sxt_kleen,index,data,satpix,kleenindex=kleenindex,$
	level=level,dat=dat,dark1=dark1,timer=timer,$
	nsmooth=nsmooth,nsigma=nsigma,nbound=nbound,debug=debug

;NAME
;	sxt_kleen
;PURPOSE
;	Front-end program to call sxt_clean.pro to retain
;	compatibility with earlier softwate.
;	Removes spikes and holes from an SXT image.
;CALLING SEQUENCE
;	nice_img=sxt_kleen(index,data,timer)
;	nice_img=sxt_kleen(index,data,[kleenindex=kleenindex,$
;          level=level,dat=dat,dark1=dark1,timer=timer,$
;          nsmooth=nsmooth,nsigma=nsigma,nbound=nbound,debug=debug]
;INPUTS
;	index, SXT index structure
;	data, either sxt_prep'd image or raw compressed SXT image
;OPTIONAL KEYWORD INPUTS
;	level, logarithmic spike threshold for signal parts of the image.
;		[default = 1.125 (FR), 0.75 (HR), 0.375 (QR)]
;	/timer, prints out how long it took program to run.
;	nsmooth, median smoothing parameter [default = 3]
;	nsigma, gaussian smoothing parameter [default = 3, sigma]
;	nbound, sets boundary between noisy and signal parts of image.
;		[default = 0.5, i.e., half the std dev of darkframe.]
;	/debug, stops program from time to time for debugging.
;OPTIONAL OUTPUTS
;	satpix, saturated pixels in byte-type input image.
;OPTIONAL KEYWORD OUTPUTS
;	kleenindex, index structure with exposure adjusted in .his
;	    (Note: Flagging of kleening not yet implemented in .his.)
;	dat, returns input data or sxt_prep'd input data.
;	dark1, returns darkframe used to determine std dev of noise.
;RESTRICTIONS
; 	THIS CODE ONLY HANDLES ONE IMAGE AT A TIME.
;	Assumes noise obeys poisson statistics.
;	SXT_KLEEN should be run before registration.
;	This program alters the data -- which is ALWAYS dangerous!
;HISTORY
;	10-Apr-00, LWA, Gutted sxt_kleen.pro
;-

if keyword_set(kleenindex) then cleanindex=kleenindex

out = sxt_clean(index,data,satpix,cleanindex=cleanindex,$
        level=level,dat=dat,dark1=dark1,timer=timer,$
        nsmooth=nsmooth,nsigma=nsigma,nbound=nbound,debug=debug,$
        xsaa=xsaa)

kleenindex=cleanindex

return, out

end
